local function d2(n)
	if n < 10 then
		return "0"..n
	else
		return n
	end
end

local nodenames = {}
for h = 0, 23 do
	local q = math.floor(h / 6)
	local s = math.mod(h, 6)
	table.insert(nodenames, "clockblock:dial_clock_"..d2(h))
	minetest.register_node("clockblock:dial_clock_"..d2(h), {
		description = "Rotating-Dial Clock showing "..d2(h),
		groups = {choppy=2,flammable=1,not_in_creative_inventory=1},
		tiles = {"clockblock_case.png^[transform"..math.mod(4 - q, 4).."^clockblock_dial_"..d2(s)..".png^[transform"..q.."^clockblock_hand_00.png"},
		drop = "clockblock:dial_clock",
	})
	table.insert(nodenames, "clockblock:hand_clock_"..d2(h))
	minetest.register_node("clockblock:hand_clock_"..d2(h), {
		description = "Rotating-Hand Clock showing "..d2(h),
		groups = {choppy=2,flammable=1,not_in_creative_inventory=1},
		tiles = {"clockblock_case.png^clockblock_dial_00.png^[transform"..q.."^clockblock_hand_"..d2(s)..".png^[transform"..math.mod(4 - q, 4)},
		drop = "clockblock:hand_clock",
	})
end

local function current_hour()
	return math.mod(math.floor(minetest.get_timeofday()*24 + 0.5), 24)
end

minetest.register_abm({
	nodenames = nodenames,
	interval = 10,
	chance = 1,
	action = function(pos, node, active_object_count, active_object_count_wider)
		local newname = node.name:gsub("..$", d2(current_hour()))
		if node.name ~= newname then
			node.name = newname
			minetest.swap_node(pos, node)
		end
	end,
})

for typecode, typedesc in pairs({ dial = "Rotating-Dial", hand = "Rotating-Hand" }) do
	minetest.register_node("clockblock:"..typecode.."_clock", {
		description = typedesc.." Clock",
		tiles = minetest.registered_nodes["clockblock:"..typecode.."_clock_03"].tiles,
		node_placement_prediction = "clockblock:"..typecode.."_clock_03",
		on_place = function (itemstack, placer, pointed_thing)
			local st = ItemStack("clockblock:"..typecode.."_clock_"..d2(current_hour()))
			st:set_count(itemstack:get_count())
			st = minetest.item_place(st, placer, pointed_thing)
			itemstack:set_count(st:get_count())
			return itemstack
		end,
	})
end

minetest.register_node("clockblock:case", {
	description = "Clock Case",
	groups = {choppy=2,flammable=1},
	sunlight_propagates = true,
	paramtype = "light",
	drawtype = "allfaces",
	tiles = {"clockblock_case.png"},
})

minetest.register_craft({
	output = "clockblock:case",
	recipe = {
		{"group:wood", "default:glass", "group:wood"},
		{"default:glass", "default:steel_ingot", "default:glass"},
		{"group:wood", "default:glass", "group:wood"},
	},
})

minetest.register_craftitem("clockblock:dial", {
	description = "Clock Dial",
	inventory_image = "clockblock_dial_03.png",
})

minetest.register_craft({
	output = "clockblock:dial",
	recipe = {
		{"default:glass", "default:steel_ingot", "default:glass"},
		{"group:stick", "default:copper_ingot", "group:stick"},
		{"default:glass", "default:gold_ingot", "default:glass"},
	},
})

minetest.register_craftitem("clockblock:hand", {
	description = "Clock Hand",
	inventory_image = "clockblock_hand_inventory.png",
})

minetest.register_craft({
	output = "clockblock:hand",
	recipe = {
		{"", "default:copper_ingot", ""},
		{"group:stick", "", "group:stick"},
		{"group:stick", "", "group:stick"},
	},
})

minetest.register_craftitem("clockblock:gear_wood", {
	description = "Wooden Clock Gear",
	inventory_image = "clockblock_gear_wood.png",
})

minetest.register_craft({
	output = "clockblock:gear_wood",
	recipe = {
		{"", "group:stick", ""},
		{"group:stick", "group:wood", "group:stick"},
		{"", "group:stick", ""},
	},
})

minetest.register_craftitem("clockblock:gear_iron", {
	description = "Iron Clock Gear",
	inventory_image = "clockblock_gear_iron.png",
})

minetest.register_craft({
	output = "clockblock:gear_iron",
	recipe = {
		{"", "clockblock:gear_wood", ""},
		{"clockblock:gear_wood", "default:steel_ingot", "clockblock:gear_wood"},
		{"", "clockblock:gear_wood", ""},
	},
})

minetest.register_craft({
	output = "clockblock:dial_clock",
	recipe = {
		{"default:mese_crystal", "clockblock:case", "default:mese_crystal"},
		{"clockblock:gear_iron", "clockblock:dial", "clockblock:gear_iron"},
		{"group:wood", "clockblock:hand", "group:wood"},
	},
})

minetest.register_craft({
	output = "clockblock:hand_clock",
	recipe = {
		{"default:mese_crystal", "clockblock:case", "default:mese_crystal"},
		{"group:wood", "clockblock:dial", "group:wood"},
		{"clockblock:gear_iron", "clockblock:hand", "clockblock:gear_iron"},
	},
})
